!*****************************************************************************
! File    : Image2PDF.inc
! Author  : Utility Warrior, (c) 2005-2008
! Project : Image to PDF (Image2PDF) Dynamic Link Library
! Purpose : This file provides Clarion prototypes for all DLL functions
!
! Notes   : To use the Image to PDF DLL with Clarion you will need to use the Clarion 
! specific files as outlined below:
!
! Put "Image2PDF Clarion.lib", "Image2PDF.inc" and "Image2PDF.DLL" into your Clarion 
! application directory 
!
! Load your Clarion Application into the Clarion IDE 
!
! Under Project/Properties > "Library, object, and resource files", press the 
! "Add File" button to add "Image2PDF Clarion.lib" 
!
! Under Application/Global/Embeds > "Inside the Global Map", add: INCLUDE('Image2PDF.inc') 
!
! NB. When you distribute your Clarion application executable ensure that you also include "Image2PDF.dll"
!
! Please refer to the accompanying documentation for full details.
!******************************************************************************

  MODULE('Image2PDF.dll')

!******************************************************************************
  I2PDF_GetDLLVersion(),ULONG,C,RAW,Name('I2PDF_GetDLLVersion')
!******************************************************************************
! This allows the support of multiple versions of a DLL (if and when
! available) so that functions that might only be available in a later version
! can then only be called if the returned version currently being used is one 
! that supports those functions.
!   
! Return value: integer value representing the DLL version, a value of 100 is
!               equivalent to version 1.00
!******************************************************************************


!******************************************************************************
! Required and Miscellaneous
!******************************************************************************


!******************************************************************************
  I2PDF_License(*CSTRING code),C,RAW,Name('I2PDF_License')
!******************************************************************************
! This is required to remove the "Evaluation Mode" message that is stamped 
! over the top of every page in the output PDF document.   
!   
! To purchase a license code please visit the Utility Warrior web site which 
! has the latest information and prices on the licenses that are available. 
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_WildcardFilenameUse(ULONG flags),ULONG,C,RAW,Name('I2PDF_WildcardFilenameUse')
!******************************************************************************
! This can only be specified if the PDF filename is *.pdf AND only one wildcarded 
! image name is used.
!   
! Note: This must be set BEFORE I2PDF_AddImage is used
!
! flags can be:
! 0 - default of one pdf produced per image with no recursion
! 1 - Per Directory (forces creation of a single PDF file - with the name of that directory and saved in that directory - for the entire contents of a directory rather than one per image
! 2 - Directory Recursion (wildcarded image filename is looked for in all sub-directories below the directory which is referenced by the wildcarded image name)
! 3 - both Per Directory and Directory Recursion
!
! Return value:
! 0 - success
! 1 - images have already been added
!******************************************************************************


!******************************************************************************
  I2PDF_AddImage(*CSTRING image),ULONG,C,RAW,Name('I2PDF_AddImage')
!******************************************************************************
! Specifies the name and location of an image to embed within the output PDF document.
!
! The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
!
! Up to 1000 images can be included.
!
! Images are embedded in the output PDF document in the order that they are referenced.
!
! Image filenames can contain the wildcard characters * and ? that allow multiple images 
! to be referenced in one go. These characters can only be in the filename and not in any 
! part of the filepath before the filename.
!
! Return value:
! 0 - success
! 1 - invalid parameter
! 2 - maximum number of images already added
! 3 - invalid image type
! 4 - image does not exist
!******************************************************************************


!******************************************************************************
  I2PDF_AddImageBookmark(*CSTRING image, *CSTRING bookmark),ULONG,C,RAW,Name('I2PDF_AddImageBookmark')
!******************************************************************************
! Specifies the name and location of an image to embed within the output PDF document.
!
! The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
!
! Up to 1000 images can be included.
!
! Images are embedded in the output PDF document in the order that they are referenced.
!
! Return value:
! 0 - success
! 1 - invalid image parameter
! 2 - maximum number of images already added
! 3 - invalid image type
! 4 - invalid bookmark parameter
! 5 - image does not exist
!******************************************************************************


!******************************************************************************
  I2PDF_Log(*CSTRING logFilename, ULONG logLevel),ULONG,C,RAW,Name('I2PDF_Log')
!******************************************************************************
! Information and error messages are appended to the end of the file specified (with a timestamp).
!
! Set logLevel to one or more (by adding required log levels together) of:
! 1 to log image width, height, bit depth and DPI for each image that is converted.
! 2 font matching information.
! 4 filename wildcard matching information.
! 8 Bates number information.
!
! Return value:
! 0 - success
! 1 - invalid logFilename
!******************************************************************************


!******************************************************************************
  I2PDF_SilentRunning(),C,RAW,Name('I2PDF_SilentRunning')
!******************************************************************************
! Prevents information from being printed to the console window.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_PreventPDFOverwrite(),C,RAW,Name('I2PDF_PreventPDFOverwrite')
!******************************************************************************
! Prevents an existing PDF from being overwritten
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SaveFailureBackupPDF(*CSTRING filename),ULONG,C,RAW,Name('I2PDF_SaveFailureBackupPDF')
!******************************************************************************
! Will save the PDF to a backup filename if the required file cannot be written (perhaps because another application has the target PDF currently open). 
!
! Return value: none 
! 0 - success
! 1 - invalid filename
!******************************************************************************


!******************************************************************************
  I2PDF_IncludeTIFFOCRText(),C,RAW,Name('I2PDF_IncludeTIFFOCRText')
!******************************************************************************
! Includes any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) as invisible "searchable" text within the PDF. 
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SaveTIFFOCRText(*CSTRING text),C,RAW,Name('I2PDF_SaveTIFFOCRText')
!******************************************************************************
! Outputs any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) into a text file with the same name and in the same location as the produced PDF.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailureCopyTo(*CSTRING copyToDir),ULONG,C,RAW,Name('I2PDF_LoadImageFailureCopyTo')
  I2PDF_LoadImageFailCopyTo(*CSTRING copyToDir),ULONG,C,RAW,Name('I2PDF_LoadImageFailCopyTo')
!******************************************************************************
! Allows images that fail to be copied to the specified directory (for a manual or monitoring process to deal with).
!
! Return value:
! 0 - success
! 1 - invalid copyToDir
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailureSkip(),C,RAW,Name('I2PDF_LoadImageFailureSkip')
  I2PDF_LoadImageFailSkip(),C,RAW,Name('I2PDF_LoadImageFailSkip')
!******************************************************************************
! Allows images that fail to be skipped over so that all valid images are still converted and a PDF produced. 
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailurePage_Real(ULONG width, ULONG height, REAL backgroundRed, REAL backgroundGreen, REAL backgroundBlue, *CSTRING message),ULONG,C,RAW,Name('I2PDF_LoadImageFailurePage_Real')
  I2PDF_LoadImageFailPg_Real(ULONG width, ULONG height, REAL backgroundRed, REAL backgroundGreen, REAL backgroundBlue, *CSTRING message),ULONG,C,RAW,Name('I2PDF_LoadImageFailPg_Real')
!******************************************************************************
! Allows images that fail to still have a page in the PDF but with the required message.
!
! Return value:
! 0 - success
! 1 - invalid width
! 2 - invalid height
! 3 - invalid backgroundRed
! 4 - invalid backgroundGreen
! 5 - invalid backgroundBlue
! 6 - invalid message 
!******************************************************************************

 
!******************************************************************************
  I2PDF_LoadImageFailurePage_Int(ULONG width, ULONG height, ULONG backgroundRed, ULONG backgroundGreen, ULONG backgroundBlue, *CSTRING message),ULONG,C,RAW,Name('I2PDF_LoadImageFailurePage_Int')
  I2PDF_LoadImageFailPg_Int(ULONG width, ULONG height, ULONG backgroundRed, ULONG backgroundGreen, ULONG backgroundBlue, *CSTRING message),ULONG,C,RAW,Name('I2PDF_LoadImageFailPg_Int')
!******************************************************************************
! Allows images that fail to still have a page in the PDF but with the required message.
!
! Return value:
! 0 - success
! 1 - invalid width
! 2 - invalid height
! 3 - invalid backgroundRed
! 4 - invalid backgroundGreen
! 5 - invalid backgroundBlue
! 6 - invalid message 
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailurePage_Web(ULONG width, ULONG height, *CSTRING backgroundColor, *CSTRING message),ULONG,C,RAW,Name('I2PDF_LoadImageFailurePage_Web')
  I2PDF_LoadImageFailPg_Web(ULONG width, ULONG height, *CSTRING backgroundColor, *CSTRING message),ULONG,C,RAW,Name('I2PDF_LoadImageFailPg_Web')
!******************************************************************************
! Allows images that fail to still have a page in the PDF but with the required message.
!
! Return value:
! 0 - success
! 1 - invalid width
! 2 - invalid height
! 3 - invalid backgroundColor
! 4 - invalid message 
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailurePageFont_Real(ULONG iSize, *CSTRING font, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG iStyle, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('I2PDF_LoadImageFailurePageFont_Real')
  I2PDF_LoadImageFailPgFnt_Real(ULONG iSize, *CSTRING font, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG iStyle, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('I2PDF_LoadImageFailPgFnt_Real')
!******************************************************************************
! Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font
! 3 - invalid fillRed
! 4 - invalid fillGreen
! 5 - invalid fillBlue
! 6 - invalid style
! 7 - invalid otherRed
! 8 - invalid otherGreen
! 9 - invalid otherBlue 
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailurePageFont_Int(ULONG iSize, *CSTRING font, ULONG fillRed, ULONG fillGreen, ULONG fillBlue, ULONG iStyle, ULONG otherRed, ULONG otherGreen, ULONG otherBlue),ULONG,C,RAW,Name('I2PDF_LoadImageFailurePageFont_Int')
  I2PDF_LoadImageFailPgFnt_Int(ULONG iSize, *CSTRING font, ULONG fillRed, ULONG fillGreen, ULONG fillBlue, ULONG iStyle, ULONG otherRed, ULONG otherGreen, ULONG otherBlue),ULONG,C,RAW,Name('I2PDF_LoadImageFailPgFnt_Int')
!******************************************************************************
! Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font
! 3 - invalid fillRed
! 4 - invalid fillGreen
! 5 - invalid fillBlue
! 6 - invalid style
! 7 - invalid otherRed
! 8 - invalid otherGreen
! 9 - invalid otherBlue 
!******************************************************************************


!******************************************************************************
  I2PDF_LoadImageFailurePageFont_Web(ULONG iSize, *CSTRING font, *CSTRING fillColor, ULONG iStyle, *CSTRING otherColor),ULONG,C,RAW,Name('I2PDF_LoadImageFailurePageFont_Web')
  I2PDF_LoadImageFailPgFnt_Web(ULONG iSize, *CSTRING font, *CSTRING fillColor, ULONG iStyle, *CSTRING otherColor),ULONG,C,RAW,Name('I2PDF_LoadImageFailPgFnt_Web')
!******************************************************************************
! Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid font
! 3 - invalid fillColor
! 4 - invalid style
! 5 - invalid otherColor 
!******************************************************************************


!******************************************************************************
  I2PDF_TreatImageNumericExtensionAs(*CSTRING imageExtension),ULONG,C,RAW,Name('I2PDF_TreatImageNumericExtensionAs')
  I2PDF_TreatImageNumericExtAs(*CSTRING imageExtension),ULONG,C,RAW,Name('I2PDF_TreatImageNumericExtAs')
!******************************************************************************
! Some images may have a numeric sequenced number extension (eg image.001, image.002 etc) which would normally prevent
! the image from being identified as a valid one. To get around this problem use this
! function and pass it the image extension type that a numeric extension will be interpreted
! as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
!
! Return value:
! 0 - success
! 1 - extension not specified
! 2 - extension does not start with a .
! 3 - extension is not 4 characters long
!******************************************************************************


!******************************************************************************
  I2PDF_TreatImageTmpExtensionAs(*CSTRING imageExtension),ULONG,C,RAW,Name('I2PDF_TreatImageTmpExtensionAs')
  I2PDF_TreatImageTmpExtAs(*CSTRING imageExtension),ULONG,C,RAW,Name('I2PDF_TreatImageTmpExtAs')
!******************************************************************************
! Some images may have a TMP extension which would normally prevent
! the image from being identified as a valid one. To get around this problem use this
! function and pass it the image extension type that a TMP extension will be interpreted
! as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
!
! Return value:
! 0 - success
! 1 - extension not specified
! 2 - extension does not start with a .
! 3 - extension is not 4 characters long
!******************************************************************************


!******************************************************************************
  I2PDF_TreatImageExtensionAs(*CSTRING sourceExtension, *CSTRING targetExtension),ULONG,C,RAW,Name('I2PDF_TreatImageExtensionAs')
  I2PDF_TreatImageExtAs(*CSTRING sourceExtension, *CSTRING targetExtension),ULONG,C,RAW,Name('I2PDF_TreatImageExtAs')
!******************************************************************************
! Some images may have a non-standard image extension which would normally prevent
! the image from being identified as a valid one. To get around this problem use this
! function to map one of these extensions as a known one
! (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
!
! Return value:
! 0 - success
! 1 - source extension not specified
! 2 - source extension does not start with a .
! 3 - target extension not specified
! 4 - target extension does not start with a .
! 5 - target extension is not 4 characters long
! 6 - max image extension mappings already defined
!******************************************************************************


!******************************************************************************
  I2PDF_MetaImageMaxMP(REAL maxmp),ULONG,C,RAW,Name('I2PDF_MetaImageMaxMP')
  I2PDF_MetaImageMaxMP_Int(ULONG maxmp),ULONG,C,RAW,Name('I2PDF_MetaImageMaxMP_Int')
!******************************************************************************
! Specifies the meta image (EMF or WMF) maximum rendering size.
!
! Return value:
! 0 - success
! 1 - invalid maxmp parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MetaImageScale(REAL percentage),ULONG,C,RAW,Name('I2PDF_MetaImageScale')
  I2PDF_MetaImageScale_Int(ULONG percentage),ULONG,C,RAW,Name('I2PDF_MetaImageScale_Int')
!******************************************************************************
! Specifies the meta image (EMF or WMF) scaling factor.
!
! Return value:
! 0 - success
! 1 - invalid percentage parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MetaVerticalRenderScale(REAL scale),ULONG,C,RAW,Name('I2PDF_MetaVerticalRenderScale')
  I2PDF_MetaVerticalRenderScale_Int(ULONG scale),ULONG,C,RAW,Name('I2PDF_MetaVerticalRenderScale_Int')
  I2PDF_MetaVertRenderScale_Int(ULONG scale),ULONG,C,RAW,Name('I2PDF_MetaVertRenderScale_Int')
!******************************************************************************
! Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
!
! Return value:
! 0 - success
! 1 - invalid scale parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MetaMargins(),C,RAW,Name('I2PDF_MetaMargins')
!******************************************************************************
! Preserve the margins around the meta image (no matter how large they might be)
!
! Return value:
! None
!******************************************************************************


!******************************************************************************
  I2PDF_MetaToNativePDF(),C,RAW,Name('I2PDF_MetaToNativePDF')
!******************************************************************************
! Forces meta image files to be converted into a native PDF representation
!
! Return value:
! None
!******************************************************************************


!******************************************************************************
  I2PDF_CenterMetaImageOnPage(),C,RAW,Name('I2PDF_CenterMetaImageOnPage')
!******************************************************************************
! Force a native rendered page to have the contents centered on the page based on the content of the meta image that is actually rendered into the PDF
!
! Return value:
! None
!******************************************************************************


!******************************************************************************
  I2PDF_MetaBitmapForcedFontQuality(ULONG quality),ULONG,C,RAW,Name('I2PDF_MetaBitmapForcedFontQuality')
  I2PDF_MetaBitmapForcedFontQ(ULONG quality),ULONG,C,RAW,Name('I2PDF_MetaBitmapForcedFontQ')
!******************************************************************************
! This API can only be used if the I2PDF_MetaToNativePDF API has NOT been used as it controls the font quality when rendering the meta image file into a bitmap. 
!
! Values that can be passed as parameters:
! FORCED_FONT_QUALITY_DRAFT As Integer            1
! FORCED_FONT_QUALITY_PROOF As Integer            2
! FORCED_FONT_QUALITY_NONANTIALIASED As Integer   3
! FORCED_FONT_QUALITY_ANIALIASED As Integer       4
! FORCED_FONT_QUALITY_CLEARTYPE As Integer        5
!
! Return value:
! 0 - success
! 1 - invalid quality
!******************************************************************************


!******************************************************************************
  I2PDF_MetaTextFitBoundingRect(),C,RAW,Name('I2PDF_MetaTextFitBoundingRect')
!******************************************************************************
! If text in a meta image file is larger than the defined bounding rectangle this command will progressively 
! reduce the font size until it can fit the text within the defined bounding area.
!
! Return value:
! None
!******************************************************************************


!******************************************************************************
  I2PDF_UseEMFDeviceSize(),C,RAW,Name('I2PDF_UseEMFDeviceSize')
!******************************************************************************
! Determine the size of an EMF meta file by using the embedded reference device bounds.
!
! Return value:
! None
!******************************************************************************


!******************************************************************************
  I2PDF_UseEMFFrameSize(),C,RAW,Name('I2PDF_UseEMFFrameSize')
!******************************************************************************
! Determine the size of an EMF meta file by using the embedded frame size.
!
! Return value:
! None
!******************************************************************************


!******************************************************************************
  I2PDF_ImageStamp(*CSTRING image, ULONG verticalPosition, ULONG horizontalPosition, REAL margin),ULONG,C,RAW,Name('I2PDF_ImageStamp')
  I2PDF_ImageStamp_Int(*CSTRING image, ULONG verticalPosition, ULONG horizontalPosition, ULONG margin),ULONG,C,RAW,Name('I2PDF_ImageStamp_Int')
!******************************************************************************
! Specifies the name and location of an image that is "stamped" at the specified location on each page of the output PDF document.
! A margin between the image stamp and the edge of the page can be specified if required.
!
! Values that can be passed as parameters:
! VERTICAL_ALIGNMENT_TOP        1
! VERTICAL_ALIGNMENT_MIDDLE     2
! VERTICAL_ALIGNMENT_BOTTOM     3
! HORIZONTAL_ALIGNMENT_LEFT     1
! HORIZONTAL_ALIGNMENT_CENTER   2
! HORIZONTAL_ALIGNMENT_RIGHT    3
!
! Return value:
! 0 - success
! 1 - invalid image parameter
! 2 - invalid vertical position
! 3 - invalid horizontal position
! 4 - invalid margin
!******************************************************************************


!******************************************************************************
  I2PDF_MetaStampImageMaxMP(REAL maxmp),ULONG,C,RAW,Name('I2PDF_MetaStampImageMaxMP')
  I2PDF_MetaStampImageMaxMP_Int(ULONG maxmp),ULONG,C,RAW,Name('I2PDF_MetaStampImageMaxMP_Int')
!******************************************************************************
! Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
!
! Return value:
! 0 - success
! 1 - invalid maxmp parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MetaStampImageScale(REAL percentage),ULONG,C,RAW,Name('I2PDF_MetaStampImageScale')
  I2PDF_MetaStampImageScale_Int(ULONG percentage),ULONG,C,RAW,Name('I2PDF_MetaStampImageScale_Int')
!******************************************************************************
! Specifies the meta image (EMF or WMF) scaling factor for an image stamp
!
! Return value:
! 0 - success
! 1 - invalid percentage parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MetaDefaultFont(*CSTRING fontname),ULONG,C,RAW,Name('I2PDF_MetaDefaultFont')
!******************************************************************************
! If a font cannot be matched then this allows the specification of one of the standard PDF fonts to be used:
!
! Courier 
! Courier-Bold 
! Courier-BoldOblique 
! Courier-Oblique 
! Helvetica 
! Helvetica-Bold 
! Helvetica-BoldOblique 
! Helvetica-Oblique 
! Times-Roman 
! Times-Bold 
! Times-Italic 
! Times-BoldItalic 
!
! Return value:
! 0 - success
! 1 - invalid font name
!******************************************************************************


!******************************************************************************
  I2PDF_MetaDefaultFontXScaling(REAL scaleFactor),ULONG,C,RAW,Name('I2PDF_MetaDefaultFontXScaling')
!******************************************************************************
! If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) then this 
! allows the arbitrary scaling of the width of the font in order to better match the actual physical 
! dimensions of the substituted font. Can only be used in conjunction with I2PDF_MetaDefaultFont
!
! Return value:
! 0 - success
! 1 - invalid scale factor parameter
!******************************************************************************


!******************************************************************************
  I2PDF_UseArabicContextualForms(),C,RAW,Name('I2PDF_UseArabicContextualForms')
  I2PDF_UseArabicContextForms(),C,RAW,Name('I2PDF_UseArabicContextForms')
!******************************************************************************
! By default, when Arabic Unicode text is used (codepage CP1256) the Arabic glyphs do not 
! take into account the context and relationship with other Arabic and non-Arabic text.
! This command will enable the analysis of the surrounding text in order to change the glyph to one of
! the contextual Arabic alternatives (known as initial, medial, final and isolated forms)
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_EmbedFonts(),C,RAW,Name('I2PDF_EmbedFonts')
!******************************************************************************
! If a document is converted which uses an unusual font that is not likely to be installed on a target 
! system then this	command will ensure that all of the font details are embedded within the PDF so that 
! the target system that a PDF may be viewed on does not require the font in order to display the text 
! within the PDF correctly.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_StampURL(*CSTRING url),ULONG,C,RAW,Name('I2PDF_StampURL')
!******************************************************************************
! This is optional and specifies the URL that the image stamp will open in the default browser when it is clicked on.
!
! A maximum of 128 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MetaToNativeFontSubstitution(*CSTRING fontSubs),ULONG,C,RAW,Name('I2PDF_MetaToNativeFontSubstitution')
  I2PDF_MetaToNativeFontSubs(*CSTRING fontSubs),ULONG,C,RAW,Name('I2PDF_MetaToNativeFontSubs')
!******************************************************************************
! If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) 
! then this allows an alternative font and specific character substitutions to be made. 
!
! Return value:
! 0 - success
! 1 - invalid substitution description
! 2 - maximum number of substitution strings already defined
!******************************************************************************


!******************************************************************************
  I2PDF_SlideShow(ULONG transition, REAL transitionDuration, REAL pageDisplayDuration),ULONG,C,RAW,Name('I2PDF_SlideShow')
  I2PDF_SlideShow_Int(ULONG transition, ULONG transitionDuration, ULONG pageDisplayDuration),ULONG,C,RAW,Name('I2PDF_SlideShow_Int')
!******************************************************************************
! Forces the PDF document to be displayed full screen with the chosen screen transition between each page.
!
! Values that can be passed as parameters:
! SLIDESHOW_WIPE_RIGHT                        1
! SLIDESHOW_WIPE_UP                           2
! SLIDESHOW_WIPE_LEFT                         3
! SLIDESHOW_WIPE_DOWN                         4
! SLIDESHOW_BARN_DOORS_HORIZONTAL_OUT         5
! SLIDESHOW_BARN_DOORS_HORIZONTAL_IN          6
! SLIDESHOW_BARN_DOORS_VERTICAL_OUT           7
! SLIDESHOW_BARN_DOORS_VERTICAL_IN            8
! SLIDESHOW_BOX_OUT                           9
! SLIDESHOW_BOX_IN                           10
! SLIDESHOW_BLINDS_HORIZONTAL                11
! SLIDESHOW_BLINDS_VERTICAL                  12
! SLIDESHOW_DISSOLVE                         13
! SLIDESHOW_GLITTER_RIGHT                    14
! SLIDESHOW_GLITTER_DOWN                     15
! SLIDESHOW_GLITTER_TOP_LEFT_TO_BOTTOM_RIGHT 16
! SLIDESHOW_REPLACE                          17
!
! Return value:
! 0 - success
! 1 - invalid transition
! 2 - invalid transition duration
! 3 - invalid page display duration
!******************************************************************************


!******************************************************************************
  I2PDF_DeleteImagesOnConvert(),C,RAW,Name('I2PDF_DeleteImagesOnConvert')
!******************************************************************************
! When the PDF document has been successfully produced all of the images converted to PDF are deleted.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SetBorder(REAL left, REAL top, REAL right, REAL bottom),ULONG,C,RAW,Name('I2PDF_SetBorder')
  I2PDF_SetBorder_Int(ULONG left, ULONG top, ULONG right, ULONG bottom),ULONG,C,RAW,Name('I2PDF_SetBorder_Int')
!******************************************************************************
! Allows a border to be inserted between the image and the edge of the PDF page.
! The border color can be specified by using one of the three I2PDF_SetBorderColor_Real/Int/Web APIs below.
! This can be useful if you want to add an image stamp to each page but do not want it to obscure the image.
!
! Return value:
! 0 - success
! 1 - invalid left value
! 2 - invalid top value
! 3 - invalid right value
! 4 - invalid bottom value
!******************************************************************************


!******************************************************************************
  I2PDF_SetBorderColor_Real(REAL red, REAL green, REAL blue),ULONG,C,RAW,Name('I2PDF_SetBorderColor_Real')
!******************************************************************************
! Set the border color to use when I2PDF_SetBorder has been used.
! Color is made up of a combination of three components: red, green and blue.
! The value of each color component controls how much of that color is displayed, with a value of
! 0.0 representing none up to a value of 100.0 representing the maximum value.
!
! Return value:
! 0 - success
! 1 - invalid red value
! 2 - invalid green value
! 3 - invalid blue value
!******************************************************************************


!******************************************************************************
  I2PDF_SetBorderColor_Int(ULONG red, ULONG green, ULONG blue),ULONG,C,RAW,Name('I2PDF_SetBorderColor_Int')
!******************************************************************************
! Set the border color to use when I2PDF_SetBorder has been used.
! Color is made up of a combination of three components: red, green and blue.
! The value of each color component controls how much of that color is displayed, with a value of
! 0 representing none up to a value of 255 representing the maximum value.
!  
! Return value:
! 0 - success
! 1 - invalid red value
! 2 - invalid green value
! 3 - invalid blue value
!******************************************************************************


!******************************************************************************
  I2PDF_SetBorderColor_Web(*CSTRING color),ULONG,C,RAW,Name('I2PDF_SetBorderColor_Web')
!******************************************************************************
! Set the border color to use when I2PDF_SetBorder has been used.
! Color is made up of a combination of three components: red, green and blue.
! Web colours are specified by using three pairs of hexadecimal digits.
! The value of each color component controls how much of that color is displayed, with a value of
! 00 representing none up to a value of FF representing the maximum value.
!   
! Return value:
! 0 - success
! 1 - invalid color value
!******************************************************************************



! *****************************************************************************
! Bates (Page/Document) Numbering
! *****************************************************************************


!******************************************************************************
  I2PDF_BatesFormat(*CSTRING format),ULONG,C,RAW,Name('I2PDF_BatesFormat')
!******************************************************************************
! Specifies the text to display on each page of the output PDF. This is typically
! a combination of static text plus one or more special Bates markup formatting labels.
! See the manual for full details.
!
! Return value:
! 0 - success
! 1 - invalid format
!******************************************************************************


!******************************************************************************
  I2PDF_BatesLocation(ULONG verticalPosition, ULONG horizontalPosition, ULONG orientation, REAL margin),ULONG,C,RAW,Name('I2PDF_BatesLocation')
!******************************************************************************
! This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
!
! Return value:
! 0 - success
! 1 - invalid verticalPosition
! 2 - invalid horizontalPosition
! 3 - invalid textOrientation
! 4 - invalid margin 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesLocation_Int(ULONG  verticalPosition, ULONG  horizontalPosition, ULONG orientation, ULONG margin),ULONG,C,RAW,Name('I2PDF_BatesLocation_Int')
!******************************************************************************
! This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
!
! Return value:
! 0 - success
! 1 - invalid verticalPosition
! 2 - invalid horizontalPosition
! 3 - invalid textOrientation
! 4 - invalid margin 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesFont_Real(ULONG iSize, *CSTRING FontID, REAL fillRed, REAL fillGreen, REAL fillBlue, ULONG iStyle, REAL otherRed, REAL otherGreen, REAL otherBlue),ULONG,C,RAW,Name('I2PDF_BatesFont_Real')
!******************************************************************************
! This is optional and controls the display of the Bates "number". 
!
! Values that can be passed as parameters:
! TEXT_STYLE_NORMAL             = 1
! TEXT_STYLE_STROKE             = 2
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid fontID
! 3 - invalid fillRed
! 4 - invalid fillGreen
! 5 - invalid fillBlue
! 6 - invalid style
! 7 - invalid otherRed
! 8 - invalid otherGreen
! 9 - invalid otherBlue 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesFont_Int(ULONG iSize, *CSTRING FontID, ULONG fillRed, ULONG fillGreen, ULONG fillBlue, ULONG iStyle, ULONG otherRed, ULONG otherGreen, ULONG otherBlue),ULONG,C,RAW,Name('I2PDF_BatesFont_Int')
!******************************************************************************
! This is optional and controls the display of the Bates "number". 
!
! Values that can be passed as parameters:
! TEXT_STYLE_NORMAL             = 1
! TEXT_STYLE_STROKE             = 2
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid fontID
! 3 - invalid fillRed
! 4 - invalid fillGreen
! 5 - invalid fillBlue
! 6 - invalid style
! 7 - invalid otherRed
! 8 - invalid otherGreen
! 9 - invalid otherBlue 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesFont_Web(ULONG iSize, *CSTRING FontID, *CSTRING fillColor, ULONG iStyle, *CSTRING otherColor),ULONG,C,RAW,Name('I2PDF_BatesFont_Web')
!******************************************************************************
! This is optional and controls the display of the Bates "number". 
!
! Values that can be passed as parameters:
! TEXT_STYLE_NORMAL             = 1
! TEXT_STYLE_STROKE             = 2
!
! Return value:
! 0 - success
! 1 - invalid size
! 2 - invalid fontID
! 3 - invalid fillColor
! 4 - invalid style
! 5 - invalid otherColor 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesFile(*CSTRING filename),ULONG,C,RAW,Name('I2PDF_BatesFile')
!******************************************************************************
! This is optional but is useful if you want to have sequential numbering continue automatically between documents. 
!
! Return value:
! 0 - success
! 1 - invalid filename
!******************************************************************************


!******************************************************************************
  I2PDF_BatesNumber(ULONG initialValue),ULONG,C,RAW,Name('I2PDF_BatesNumber')
!******************************************************************************
! This is optional and defines the initial Bates number used. 
!
! Return value:
! 0 - success
!******************************************************************************


!******************************************************************************
  I2PDF_BatesIncrement(ULONG value),ULONG,C,RAW,Name('I2PDF_BatesIncrement')
!******************************************************************************
! This is optional and defines the amount by which the Bates number is incremented with use. 
!
! Return value:
! 0 - success
! 1 - invalid value
!******************************************************************************


!******************************************************************************
  I2PDF_BatesBackground_Real(ULONG shape, REAL backgroundRed, REAL backgroundGreen, REAL backgroundBlue, REAL borderRed, REAL borderGreen, REAL borderBlue),ULONG,C,RAW,Name('I2PDF_BatesBackground_Real')
!******************************************************************************
! This is optional and if not specified no background is displayed behind the Bates "number". 
!
! Values that can be passed as parameters:
! BATES_BACKGROUND_FILLED_RECT  = 1
! BATES_BACKGROUND_OUTLINE_RECT = 2
!
! Return value:
! 0 - success
! 1 - invalid shape
! 2 - invalid backgroundRed
! 3 - invalid backgroundGreen
! 4 - invalid backgroundBlue
! 5 - invalid borderRed
! 6 - invalid borderGreen
! 7 - invalid borderBlue 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesBackground_Int(ULONG shape, ULONG backgroundRed, ULONG backgroundGreen, ULONG backgroundBlue, ULONG borderRed, ULONG borderGreen, ULONG borderBlue),ULONG,C,RAW,Name('I2PDF_BatesBackground_Int')
!******************************************************************************
! This is optional and if not specified no background is displayed behind the Bates "number". 
!
! Values that can be passed as parameters:
! BATES_BACKGROUND_FILLED_RECT  = 1
! BATES_BACKGROUND_OUTLINE_RECT = 2
!
! Return value:
! 0 - success
! 1 - invalid shape
! 2 - invalid backgroundRed
! 3 - invalid backgroundGreen
! 4 - invalid backgroundBlue
! 5 - invalid borderRed
! 6 - invalid borderGreen
! 7 - invalid borderBlue 
!******************************************************************************


!******************************************************************************
  I2PDF_BatesBackground_Web(ULONG shape, *CSTRING backgroundColor, *CSTRING borderColor),ULONG,C,RAW,Name('I2PDF_BatesBackground_Web')
!******************************************************************************
! This is optional and if not specified no background is displayed behind the Bates "number". 
!
! Values that can be passed as parameters:
! BATES_BACKGROUND_FILLED_RECT  = 1
! BATES_BACKGROUND_OUTLINE_RECT = 2
!
! Return value:
! 0 - success
! 1 - invalid shape
! 2 - invalid backgroundColor
! 3 - invalid borderColor 
!******************************************************************************


!******************************************************************************
! Image transformations
!******************************************************************************


!******************************************************************************
  I2PDF_Rotate(ULONG angle),ULONG,C,RAW,Name('I2PDF_Rotate')
!******************************************************************************
! Rotate image clockwise by a fixed amount (90, 180 or 270 degrees)
!
! Return value:
! 0 - success
! 1 - invalid angle
!******************************************************************************
	

!******************************************************************************
  I2PDF_AutoRotate(ULONG orientation, ULONG angle),ULONG,C,RAW,Name('I2PDF_AutoRotate')
!******************************************************************************
! Rotate image clockwise (if required) by a fixed amount (90 or 270 degrees) 
! so that it is in portrait or landscape orientation
!
! Values that can be passed as parameters:
! AUTOROTATE_PORTRAIT   1
! AUTOROTATE_LANDSCAPE  2
!
! Return value:
! 0 - success
! 1 - invalid orientation
! 2 - invalid angle
!******************************************************************************
	

!******************************************************************************
  I2PDF_Flip(ULONG orientation),ULONG,C,RAW,Name('I2PDF_Flip')
!******************************************************************************
! Flip image horizontally (mirroring) or vertically
!
! Values that can be passed as parameters:
! FLIP_HORIZONTAL  1
! FLIP_VERTICAL    2
!
! Return value:
! 0 - success
! 1 - invalid orientation
!******************************************************************************
	

!******************************************************************************
  I2PDF_Grayscale(),C,RAW,Name('I2PDF_Grayscale')
!******************************************************************************
! Ensure that an image is in grayscale - if it is in color it will be converted
!
! Return value:
! None
!******************************************************************************
	

!******************************************************************************
  I2PDF_Negative(),C,RAW,Name('I2PDF_Negative')
!******************************************************************************
! Invert (negative) image
!
! Return value:
! None
!******************************************************************************
	

!******************************************************************************
  I2PDF_JpegCompress(ULONG quality),ULONG,C,RAW,Name('I2PDF_JpegCompress')
!******************************************************************************
! Force re-compression of all JPEG images, quality can be between 1 (low)
! to 35 (high). A value of 0 will turn re-compression off.
!
! Return value:
! 0 - success
! 1 - invalid angle
!******************************************************************************



!******************************************************************************
! PDF Settings
!******************************************************************************


!******************************************************************************
  I2PDF_SetOutline(ULONG format, ULONG style),ULONG,C,RAW,Name('I2PDF_SetOutline')
!******************************************************************************
! This turns on the generation of a bookmark for each image that is in the 
! output PDF document.
!
! Values that can be passed as parameters:
! OUTLINE_FORMAT_FILENAME  1
! OUTLINE_FORMAT_NAME      2
! STYLE_NONE               0
! STYLE_LOWERCASE          1
! STYLE_UPPERCASE          2
! STYLE_CAPITALISE         3
!
! format can be either "filename" (this is the name of the image file including 
! the image extension but not including the full filepath) or "name" (same as 
! filename but without the image extension).
!
! style can be: "lowercase", "uppercase", "capitalise" or "none".
!
! Return value:
! 0 - success
! 1 - invalid format parameter
! 2 - invalid style parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetOutlineTitle(*CSTRING code),ULONG,C,RAW,Name('I2PDF_SetOutlineTitle')
!******************************************************************************
! If an outline is created this will set the title to be used instead of the default one.
!
! Return value:
! 0 - success
! 1 - title not specified
! 2 - title too long
!******************************************************************************


!******************************************************************************
  I2PDF_SetPermissions(ULONG iPermissions),ULONG,C,RAW,Name('I2PDF_SetPermissions')
!******************************************************************************
! Allows the setting of any combination of permissions in one go
!
! Values that can be passed as parameters:
! PDF_PERMISSION_READ_ONLY    0
! PDF_PERMISSION_EDIT         1 
! PDF_PERMISSION_EDIT_EXTRA   2
! PDF_PERMISSION_COPY         4
! PDF_PERMISSION_PRINT        8
!
! Return value:
! 0 - success
! 1 - invalid permissions
!******************************************************************************


!******************************************************************************
  I2PDF_SetPermissionEdit(),C,RAW,Name('I2PDF_SetPermissionEdit')
!******************************************************************************
! Allows editing/changing of the PDF document but NOT adding or changing of text 
! notes and AcroForm fields.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SetPermissionEditExtra(),C,RAW,Name('I2PDF_SetPermissionEditExtra')
!******************************************************************************
! Allows the adding and changing of text notes and AcroForm fields within a PDF document.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SetPermissionCopy(),C,RAW,Name('I2PDF_SetPermissionCopy')
!******************************************************************************
! Allows the copying of text and graphics from the PDF document.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SetPermissionPrint(),C,RAW,Name('I2PDF_SetPermissionPrint')
!******************************************************************************
! Allows printing of the PDF document.
!
! Return value: none 
!******************************************************************************


!******************************************************************************
  I2PDF_SetOwnerPassword(*CSTRING password),ULONG,C,RAW,Name('I2PDF_SetOwnerPassword')
!******************************************************************************
! The owner of a PDF document would enter this password in order to view it
! and make changes and perform actions that may be restricted to a normal user.
!
! A maximum of 32 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetUserPassword(*CSTRING password),ULONG,C,RAW,Name('I2PDF_SetUserPassword')
!******************************************************************************
! In order that only the intended user can view the PDF document, they must type
! in this password, otherwise the user is not allowed to read the PDF document.
!
! A maximum of 32 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_EncryptionLevel(ULONG level, ULONG force),ULONG,C,RAW,Name('I2PDF_EncryptionLevel')
!******************************************************************************
! Specifies the level of encryption that is to be used on the PDF document. 
! If not specified the default level of 40 bits is used. 
!
! level must be either 40 (low) or 128 (high)
! force must be 1 to force the encryption or 0
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_MinImageSize(ULONG width, ULONG height),ULONG,C,RAW,Name('I2PDF_MinImageSize')
!******************************************************************************
! Specifies the minimum image width and height required for an image to be converted.
!
! width and height must be > 0
!
! Return value:
! 0 - success
! 1 - invalid width
! 2 - invalid height
!******************************************************************************


!******************************************************************************
  I2PDF_SetDPI(ULONG dpi),ULONG,C,RAW,Name('I2PDF_SetDPI')
!******************************************************************************
! PDF documents use a default resolution setting of 72 DPI. Images created for 
! screen display under Windows will probably have a resolution of 96 DPI. If you 
! have created images for printing then you will probably need to use 300 or 600 DPI.
!
! If you do not adjust the default resolution setting then when displayed within a 
! PDF document on screen a 96 DPI image will appear 25% larger than expected. This 
! gets much worse for a 300 DPI image which will appear 416% larger than expected.
!
! dpi must be between 9 and 2880 inclusive, or 0 to force the use of the actual
! image dpi that is recorded in the image file
!
! Return value:
! 0 - success
! 1 - invalid parameter - dpi specified is less than 9
! 2 - invalid parameter - dpi specified is greater than 2880
!******************************************************************************


!******************************************************************************
! PDF Meta Information
!******************************************************************************


!******************************************************************************
  I2PDF_SetProducer(*CSTRING producer),ULONG,C,RAW,Name('I2PDF_SetProducer')
!******************************************************************************
! The name of the application that converted the document from its native format to PDF.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetCreator(*CSTRING creator),ULONG,C,RAW,Name('I2PDF_SetCreator')
!******************************************************************************
! If the document was converted into a PDF document from another form, this is 
! usually the name of the application that created the original document.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetAuthor(*CSTRING author),ULONG,C,RAW,Name('I2PDF_SetAuthor')
!******************************************************************************
! The name of the person who created the PDF document.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetTitle(*CSTRING title),ULONG,C,RAW,Name('I2PDF_SetTitle')
!******************************************************************************
! The PDF document's title.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetSubject(*CSTRING subject),ULONG,C,RAW,Name('I2PDF_SetSubject')
!******************************************************************************
! The PDF document's subject.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetKeywords(*CSTRING keywords),ULONG,C,RAW,Name('I2PDF_SetKeywords')
!******************************************************************************
! A list of keywords associated with the PDF document.
!
! A maximum of 256 characters can be used.
!
! Return value:
! 0 - success
! 1 - invalid parameter
!******************************************************************************


!******************************************************************************
  I2PDF_SetCreationDate(),C,RAW,Name('I2PDF_SetCreationDate')
!******************************************************************************
! The date that the PDF document was created.
!
! This is set using the current local time of the PC.
!
! Return value: none
!******************************************************************************


!******************************************************************************
! PDF Viewer Preferences
!******************************************************************************


!******************************************************************************
  I2PDF_SetViewerPreferenceCenterWindow(),C,RAW,Name('I2PDF_SetViewerPreferenceCenterWindow')
  I2PDF_SetViewPrefCenterWindow(),C,RAW,Name('I2PDF_SetViewPrefCenterWindow')
!******************************************************************************
! The window displaying the PDF document should be displayed in the center of 
! the computer's screen.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetViewerPreferenceHideToolbar(),C,RAW,Name('I2PDF_SetViewerPreferenceHideToolbar')
  I2PDF_SetViewPrefHideToolbar(),C,RAW,Name('I2PDF_SetViewPrefHideToolbar')
!******************************************************************************
! The PDF viewer's toolbar should be hidden when the PDF document is active.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetViewerPreferenceHideMenubar(),C,RAW,Name('I2PDF_SetViewerPreferenceHideMenubar')
  I2PDF_SetViewPrefHideMenubar(),C,RAW,Name('I2PDF_SetViewPrefHideMenubar')
!******************************************************************************
! The PDF viewer's menubar should be hidden when the PDF document is active.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetViewerPreferenceHideWindowUI(),C,RAW,Name('I2PDF_SetViewerPreferenceHideWindowUI')
  I2PDF_SetViewPrefHideWindowUI(),C,RAW,Name('I2PDF_SetViewPrefHideWindowUI')
!******************************************************************************
! The user interface elements within the PDF document's window should be hidden.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetViewerPreferenceFitWindow(),C,RAW,Name('I2PDF_SetViewerPreferenceFitWindow')
  I2PDF_SetViewPrefFitWindow(),C,RAW,Name('I2PDF_SetViewPrefFitWindow')
!******************************************************************************
! The PDF viewer should resize the window displaying the PDF document to fit the 
! size of the first displayed page of the PDF document.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageModeOutlines(),C,RAW,Name('I2PDF_SetPageModeOutlines')
!******************************************************************************
! The PDF viewer should show the outline (ie bookmark) navigation item when the 
! PDF document is open.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageModeNone(),C,RAW,Name('I2PDF_SetPageModeNone')
!******************************************************************************
! The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
! items when the PDF document is open.
!
! This is the default if no other page mode is specified.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageModeUseThumbs(),C,RAW,Name('I2PDF_SetPageModeUseThumbs')
!******************************************************************************
! The PDF viewer should show the thumbnail navigation item when the PDF document 
! is open.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageModeFullScreen(),C,RAW,Name('I2PDF_SetPageModeFullScreen')
!******************************************************************************
! The PDF viewer should open the PDF document in full-screen mode without showing 
! the menu bar, window controls or any other window.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageLayoutSinglePage(),C,RAW,Name('I2PDF_SetPageLayoutSinglePage')
!******************************************************************************
! Display the pages one page at a time.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageLayoutOneColumn(),C,RAW,Name('I2PDF_SetPageLayoutOneColumn')
  I2PDF_SetPageLayout1Col(),C,RAW,Name('I2PDF_SetPageLayout1Col')
!******************************************************************************
! Display the pages in one column.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageLayoutTwoColumnLeft(),C,RAW,Name('I2PDF_SetPageLayoutTwoColumnLeft')
  I2PDF_SetPageLayout2ColLeft(),C,RAW,Name('I2PDF_SetPageLayout2ColLeft')
!******************************************************************************
! Display the pages in two columns, with odd-numbered pages on the left.
!
! Return value: none
!******************************************************************************


!******************************************************************************
  I2PDF_SetPageLayoutTwoColumnRight(),C,RAW,Name('I2PDF_SetPageLayoutTwoColumnRight')
  I2PDF_SetPageLayout2ColRight(),C,RAW,Name('I2PDF_SetPageLayout2ColRight')
!******************************************************************************
! Display the pages in two columns, with odd-numbered pages on the right.
!
! Return value: none
!******************************************************************************


!******************************************************************************
! Specifies the name and location of the produced PDF document
!******************************************************************************

!******************************************************************************
  I2PDF_MakePDF(*CSTRING output, ULONG options, *CSTRING errorText, ULONG maxErrorTextSize),ULONG,C,RAW,Name('I2PDF_MakePDF')
!******************************************************************************
! Generate the output PDF according to the settings already selected through
! the Application Programming Interface functions above.
!
! To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
! bit flag in the options parameter.
!
! To have all settings applied reset after PDF has been generated set the OPTION_RESET
! bit flag in the options parameter.
!
! Values that can be passed as parameters:
! OPTION_NONE      0
! OPTION_OPEN_PDF  1
! OPTION_RESET     2
!
! Return value:
! 0 - success
! 1 - invalid parameter
! 2 - output pdf could not be opened
! 3 - internal PDF generation error - error description returned in errorText
! 4 - PDF file already exists and could not be overwritten - it is possibly being held open by a PDF viewer application
!******************************************************************************

!******************************************************************************
  I2PDF_Reset(),C,RAW,Name('I2PDF_Reset')
!******************************************************************************
! Reset all settings including the list of images added.
!
! Return value: none
!******************************************************************************

  END
