' *****************************************************************************
' File    : Image2PDF.vb
' Author  : Utility Warrior, (c) 2005-2008
' Project : Image to PDF (Image2PDF) Dynamic Link Library
' Purpose : This file provides VB.net prototypes for all DLL functions
'
' Please refer to the accompanying documentation for full details.
' *****************************************************************************

Imports System.Runtime.InteropServices

Public Class Win32
    ' *************************************************************************
    ' This allows the support of multiple versions of a DLL (if and when
    ' available) so that functions that might only be available in a later
    ' version can then only be called if the returned version currently being 
    ' used is one that supports those functions.
    '   
    ' Return value: integer value representing the DLL version
    ' a value of 100 is equivalent to version 1.00
    ' *************************************************************************
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_GetDLLVersion() As Integer
    End Function

    ' *************************************************************************
    ' Required and Miscellaneous
    ' *************************************************************************
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_License(ByVal code As String)
    End Sub
    ' This is required to remove the "Evaluation Mode" message that is stamped 
    ' over the top of every page in the output PDF document.   
    '
    ' To purchase a license code please visit the Utility Warrior web site which 
    ' has the latest information and prices on the licenses that are available. 
    '
    ' Return value: none 

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_WildcardFilenameUse(ByVal flags As Integer) As Integer
    End Function
	' This can only be specified if the PDF filename is *.pdf AND only one wildcarded 
	' image name is used.
	'   
	' Note: This must be set BEFORE I2PDF_AddImage is used
	'
	' flags can be:
	' 0 - default of one pdf produced per image with no recursion
	' 1 - Per Directory (forces creation of a single PDF file - with the name of that directory and saved in that directory - for the entire contents of a directory rather than one per image
	' 2 - Directory Recursion (wildcarded image filename is looked for in all sub-directories below the directory which is referenced by the wildcarded image name)
	' 3 - both Per Directory and Directory Recursion
	'
	' Return value:
	' 0 - success
	' 1 - images have already been added

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_AddImage(ByVal image As String) As Integer
    End Function
    ' Specifies the name and location of an image to embed within the output PDF 
    ' document. The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
    '
    ' Up to 1000 images can be included.
    '
    ' Images are embedded in the output PDF document in the order that they are 
    ' referenced.
    '
    ' Image filenames can contain the wildcard characters * and ? that allow multiple images 
    ' to be referenced in one go. These characters can only be in the filename and not in any 
    ' part of the filepath before the filename.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter
    ' 2 - maximum number of images already added
    ' 3 - invalid image type
	' 4 - image does not exist


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_AddImageBookmark(ByVal image As String, ByVal bookmark As String) As Integer
    End Function
    ' Specifies the name and location of an image to embed within the output PDF 
    ' document. The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
    '
    ' Up to 1000 images can be included.
    '
    ' Images are embedded in the output PDF document in the order that they are 
    ' referenced.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid image parameter
    ' 2 - maximum number of images already added
    ' 3 - invalid image type
    ' 4 - invalid bookmark parameter
	' 5 - image does not exist


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_Log(ByVal logFilename As String, ByVal logLevel As Integer) As Integer
    End Function
	' Information and error messages are appended to the end of the file specified (with a timestamp).
	'
    ' Set logLevel to one or more (by adding required log levels together) of:
    ' 1 to log image width, height, bit depth and DPI for each image that is converted.
    ' 2 font matching information.
    ' 4 filename wildcard matching information.
    ' 8 Bates number information.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid logFilename


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_TreatImageNumericExtensionAs(ByVal imageExtension As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_TreatImageNumericExtAs(ByVal imageExtension As String) As Integer
    End Function
    ' Some images may have a numeric sequenced number extension (eg image.001, image.002 etc) which would normally prevent
    ' the image from being identified as a valid one. To get around this problem use this
    ' function and pass it the image extension type that a numeric extension will be interpreted
    ' as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
    '
    ' Return value:
    ' 0 - success
    ' 1 - extension not specified
    ' 2 - extension does not start with a .
    ' 3 - extension is not 4 characters long


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_TreatImageTmpExtensionAs(ByVal imageExtension As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_TreatImageTmpExtAs(ByVal imageExtension As String) As Integer
    End Function
    ' Some images may have a TMP extension which would normally prevent
    ' the image from being identified as a valid one. To get around this problem use this
    ' function and pass it the image extension type that a TMP extension will be interpreted
    ' as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
    '
    ' Return value:
    ' 0 - success
    ' 1 - extension not specified
    ' 2 - extension does not start with a .
    ' 3 - extension is not 4 characters long


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_TreatImageExtensionAs(ByVal sourceExtension As String, ByVal targetExtension As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_TreatImageExtAs(ByVal sourceExtension As String, ByVal targetExtension As String) As Integer
    End Function
    ' Some images may have a non-standard image extension which would normally prevent
    ' the image from being identified as a valid one. To get around this problem use this
    ' function to map one of these extensions as a known one
    ' (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
    '
    ' Return value:
    ' 0 - success
    ' 1 - source extension not specified
    ' 2 - source extension does not start with a .
    ' 3 - target extension not specified
    ' 4 - target extension does not start with a .
    ' 5 - target extension is not 4 characters long
    ' 6 - max image extension mappings already defined


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_MetaImageMaxMP(ByVal maxmp As Double) As Integer
    End Function
	' Specifies the meta image (EMF or WMF) maximum rendering size.
	'
	' Return value:
	' 0 - success
	' 1 - invalid maxmp parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_MetaImageMaxMP_Int(ByVal maxmp As Integer) As Integer
    End Function
	' Specifies the meta image (EMF or WMF) maximum rendering size.
	'
	' Return value:
	' 0 - success
	' 1 - invalid maxmp parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_MetaImageScale(ByVal percentage As Double) As Integer
    End Function
	' Specifies the meta image (EMF or WMF) scaling factor.
	'
	' Return value:
	' 0 - success
	' 1 - invalid percentage parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_MetaImageScale_Int(ByVal percentage As Integer) As Integer
    End Function
	' Specifies the meta image (EMF or WMF) scaling factor.
	'
	' Return value:
	' 0 - success
	' 1 - invalid percentage parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Function I2PDF_MetaVerticalRenderScale(ByVal scale As Double) As Integer
    End Function
	' Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
	'
	' Return value:
	' 0 - success
	' 1 - invalid scale parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaVerticalRenderScale_Int(ByVal scale As Integer) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaVertRenderScale_Int(ByVal scale As Integer) As Integer
    End Function
    ' Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid scale parameter


	<DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Sub I2PDF_MetaMargins()
	End Sub
	' Preserve the margins around the meta image (no matter how large they might be)
	'
	' Return value:
	' None


	<DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Sub I2PDF_MetaToNativePDF()
	End Sub
	' Forces meta image files to be converted into a native PDF representation
	'
	' Return value:
	' None


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_CenterMetaImageOnPage()
    End Sub
    ' Force a native rendered page to have the contents centered on the page based on the content of the meta image that is actually rendered into the PDF
    '
    ' Return value: none 


    Public Const FORCED_FONT_QUALITY_DRAFT As Integer = 1
    Public Const FORCED_FONT_QUALITY_PROOF As Integer = 2
    Public Const FORCED_FONT_QUALITY_NONANTIALIASED As Integer = 3
    Public Const FORCED_FONT_QUALITY_ANIALIASED As Integer = 4
    Public Const FORCED_FONT_QUALITY_CLEARTYPE As Integer = 5
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaBitmapForcedFontQuality(ByVal quality As Integer) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaBitmapForcedFontQ(ByVal quality As Integer) As Integer
    End Function
    ' This API can only be used if the I2PDF_MetaToNativePDF API has NOT been used as it controls the font quality when rendering the meta image file into a bitmap. 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid quality


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_MetaTextFitBoundingRect()
    End Sub
    ' If text in a meta image file is larger than the defined bounding rectangle this command will progressively 
    ' reduce the font size until it can fit the text within the defined bounding area.
    '
    ' Return value:
    ' None


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_UseEMFDeviceSize()
    End Sub
    ' Determine the size of an EMF meta file by using the embedded reference device bounds.
    '
    ' Return value:
    ' None


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_UseEMFFrameSize()
    End Sub
    ' Determine the size of an EMF meta file by using the embedded frame size.
    '
    ' Return value:
    ' None


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaDefaultFont(ByVal fontname As String) As Integer
    End Function
    ' If a font cannot be matched then this allows the specification of one of the standard PDF fonts to be used:
    '
    ' Courier 
    ' Courier-Bold 
    ' Courier-BoldOblique 
    ' Courier-Oblique 
    ' Helvetica 
    ' Helvetica-Bold 
    ' Helvetica-BoldOblique 
    ' Helvetica-Oblique 
    ' Times-Roman 
    ' Times-Bold 
    ' Times-Italic 
    ' Times-BoldItalic 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid font name


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaDefaultFontXScaling(ByVal scaleFactor As Double) As Integer
    End Function
	' If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) then this 
	' allows the arbitrary scaling of the width of the font in order to better match the actual physical 
	' dimensions of the substituted font. Can only be used in conjunction with I2PDF_MetaDefaultFont
	'
	' Return value:
	' 0 - success
	' 1 - invalid scale factor parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Sub I2PDF_UseArabicContextualForms()
	End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_UseArabicContextForms()
    End Sub
    ' By default, when Arabic Unicode text is used (codepage CP1256) the Arabic glyphs do not 
    ' take into account the context and relationship with other Arabic and non-Arabic text.
    ' This command will enable the analysis of the surrounding text in order to change the glyph to one of
    ' the contextual Arabic alternatives (known as initial, medial, final and isolated forms)
    '
    ' Return value: none 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
	Public Shared Sub I2PDF_EmbedFonts()
	End Sub
	' If a document is converted which uses an unusual font that is not likely to be installed on a target 
	' system then this	command will ensure that all of the font details are embedded within the PDF so that 
	' the target system that a PDF may be viewed on does not require the font in order to display the text 
	' within the PDF correctly.
	'
	' Return value: none 


    Public Const VERTICAL_ALIGNMENT_TOP As Integer = 1
    Public Const VERTICAL_ALIGNMENT_MIDDLE As Integer = 2
    Public Const VERTICAL_ALIGNMENT_BOTTOM As Integer = 3
    Public Const HORIZONTAL_ALIGNMENT_LEFT As Integer = 1
    Public Const HORIZONTAL_ALIGNMENT_CENTER As Integer = 2
    Public Const HORIZONTAL_ALIGNMENT_RIGHT As Integer = 3
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_ImageStamp(ByVal image As String, ByVal verticalPosition As Integer, ByVal horizontalPosition As Integer, ByVal margin As Double) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_ImageStamp_Int(ByVal image As String, ByVal verticalPosition As Integer, ByVal horizontalPosition As Integer, ByVal margin As Integer) As Integer
    End Function
    ' Specifies the name and location of an image that is "stamped" at the specified 
    ' location on each page of the output PDF document. A margin between the image
    ' stamp and the edge of the page can be specified if required.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid image parameter
    ' 2 - invalid vertical position
    ' 3 - invalid horizontal position
    ' 4 - invalid margin


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaStampImageMaxMP(ByVal maxmp As Double) As Integer
    End Function
    ' Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid maxmp parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaStampImageMaxMP_Int(ByVal maxmp As Integer) As Integer
    End Function
    ' Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid maxmp parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaStampImageScale(ByVal percentage As Double) As Integer
    End Function
    ' Specifies the meta image (EMF or WMF) scaling factor for an image stamp
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid percentage parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaStampImageScale_Int(ByVal percentage As Integer) As Integer
    End Function
    ' Specifies the meta image (EMF or WMF) scaling factor for an image stamp
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid percentage parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_StampURL(ByVal url As String) As Integer
    End Function
    ' This is optional and specifies the URL that the image stamp will open in the default browser when it is clicked on.
    '
    ' A maximum of 128 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaToNativeFontSubstitution(ByVal fontSubs As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MetaToNativeFontSubs(ByVal fontSubs As String) As Integer
    End Function
    ' If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) 
    ' then this allows an alternative font and specific character substitutions to be made. 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid substitution description
    ' 2 - maximum number of substitution strings already defined


    Public Const SLIDESHOW_WIPE_RIGHT As Integer = 1
    Public Const SLIDESHOW_WIPE_UP As Integer = 2
    Public Const SLIDESHOW_WIPE_LEFT As Integer = 3
    Public Const SLIDESHOW_WIPE_DOWN As Integer = 4
    Public Const SLIDESHOW_BARN_DOORS_HORIZONTAL_OUT As Integer = 5
    Public Const SLIDESHOW_BARN_DOORS_HORIZONTAL_IN As Integer = 6
    Public Const SLIDESHOW_BARN_DOORS_VERTICAL_OUT As Integer = 7
    Public Const SLIDESHOW_BARN_DOORS_VERTICAL_IN As Integer = 8
    Public Const SLIDESHOW_BOX_OUT As Integer = 9
    Public Const SLIDESHOW_BOX_IN As Integer = 10
    Public Const SLIDESHOW_BLINDS_HORIZONTAL As Integer = 11
    Public Const SLIDESHOW_BLINDS_VERTICAL As Integer = 12
    Public Const SLIDESHOW_DISSOLVE As Integer = 13
    Public Const SLIDESHOW_GLITTER_RIGHT As Integer = 14
    Public Const SLIDESHOW_GLITTER_DOWN As Integer = 15
    Public Const SLIDESHOW_GLITTER_TOP_LEFT_TO_BOTTOM_RIGHT As Integer = 16
    Public Const SLIDESHOW_REPLACE As Integer = 17
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SlideShow(ByVal transition As Integer, ByVal transitionDuration As Double, ByVal pageDisplayDuration As Double) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SlideShow_Int(ByVal transition As Integer, ByVal transitionDuration As Integer, ByVal pageDisplayDuration As Integer) As Integer
    End Function
    ' Forces the PDF document to be displayed full screen with the chosen screen transition between each page.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid transition
    ' 2 - invalid transition duration
    ' 3 - invalid page display duration


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_DeleteImagesOnConvert()
    End Sub
    ' When the PDF document has been successfully produced all of the images converted to PDF are deleted.
    '
    ' Return value: none 

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetBorder(ByVal left As Double, ByVal top As Double, ByVal right As Double, ByVal bottom As Double) As Long
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetBorder_Int(ByVal left As Long, ByVal top As Long, ByVal right As Long, ByVal bottom As Long) As Long
    End Function
    ' Allows a border to be inserted between the image and the edge of the PDF page.
    ' The border color can be specified by using one of the three I2PDF_SetBorderColor_Real/Int/Web APIs below.
    ' This can be useful if you want to add an image stamp to each page but do not want it to obscure the image.
    '
    ' Return value:
    '  0 - success
    '  1 - invalid left value
    '  2 - invalid top value
    '  3 - invalid right value
    '  4 - invalid bottom value

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetBorderColor_Real(ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Long
    End Function
    ' Set the border color to use when I2PDF_SetBorder has been used.
    ' Color is made up of a combination of three components: red, green and blue.
    ' The value of each color component controls how much of that color is displayed, with a value of
    ' 0.0 representing none up to a value of 100.0 representing the maximum value.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid red value
    ' 2 - invalid green value
    ' 3 - invalid blue value

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetBorderColor_Int(ByVal red As Integer, ByVal green As Integer, ByVal blue As Integer) As Long
    End Function
    ' Set the border color to use when I2PDF_SetBorder has been used.
    ' Color is made up of a combination of three components: red, green and blue.
    ' The value of each color component controls how much of that color is displayed, with a value of
    ' 0 representing none up to a value of 255 representing the maximum value.
    '   
    ' Return value:
    ' 0 - success
    ' 1 - invalid red value
    ' 2 - invalid green value
    ' 3 - invalid blue value

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetBorderColor_Web(ByVal color As String) As Long
    End Function
    ' Set the border color to use when I2PDF_SetBorder has been used.
    ' Color is made up of a combination of three components: red, green and blue.
    ' Web colours are specified by using three pairs of hexadecimal digits.
    ' The value of each color component controls how much of that color is displayed, with a value of
    ' 00 representing none up to a value of FF representing the maximum value.
    '   
    ' Return value:
    ' 0 - success
    ' 1 - invalid color value


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SilentRunning()
    End Sub
    ' Prevents information from being printed to the console window
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_PreventPDFOverwrite()
    End Sub
    ' Prevents an existing PDF from being overwritten
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SaveFailureBackupPDF(ByVal filename As String) As Integer
    End Function
    ' Will save the PDF to a backup filename if the required file cannot be written (perhaps because another application has the target PDF currently open). 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid filename


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_IncludeTIFFOCRText()
    End Sub
    ' Includes any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) as invisible "searchable" text within the PDF. 
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SaveTIFFOCRText(ByVal text As String)
    End Sub
    ' Outputs any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) into a text file with the same name and in the same location as the produced PDF.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailureCopyTo(ByVal copyToDir As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailCopyTo(ByVal copyToDir As String) As Integer
    End Function
    ' Allows images that fail to be copied to the specified directory (for a manual or monitoring process to deal with).
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid copyToDir


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_LoadImageFailureSkip()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_LoadImageFailSkip()
    End Sub
    ' Allows images that fail to be skipped over so that all valid images are still converted and a PDF produced. 
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailurePage_Real(ByVal width As Integer, ByVal height As Integer, ByVal dblBackgroundRed As Double, ByVal dblBackgroundGreen As Double, ByVal dblBackgroundBlue As Double, ByVal message As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailPg_Real(ByVal width As Integer, ByVal height As Integer, ByVal dblBackgroundRed As Double, ByVal dblBackgroundGreen As Double, ByVal dblBackgroundBlue As Double, ByVal message As String) As Integer
    End Function
    ' Allows images that fail to still have a page in the PDF but with the required message.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid width
    ' 2 - invalid height
    ' 3 - invalid backgroundRed
    ' 4 - invalid backgroundGreen
    ' 5 - invalid backgroundBlue
    ' 6 - invalid message 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailurePage_Int(ByVal width As Integer, ByVal height As Integer, ByVal backgroundRed As Integer, ByVal backgroundGreen As Integer, ByVal backgroundBlue As Integer, ByVal message As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailPg_Int(ByVal width As Integer, ByVal height As Integer, ByVal backgroundRed As Integer, ByVal backgroundGreen As Integer, ByVal backgroundBlue As Integer, ByVal message As String) As Integer
    End Function
    ' Allows images that fail to still have a page in the PDF but with the required message.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid width
    ' 2 - invalid height
    ' 3 - invalid backgroundRed
    ' 4 - invalid backgroundGreen
    ' 5 - invalid backgroundBlue
    ' 6 - invalid message 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailurePage_Web(ByVal width As Integer, ByVal height As Integer, ByVal backgroundColor As String, ByVal ByValmessage As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailPg_Web(ByVal width As Integer, ByVal height As Integer, ByVal backgroundColor As String, ByVal ByValmessage As String) As Integer
    End Function
    ' Allows images that fail to still have a page in the PDF but with the required message.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid width
    ' 2 - invalid height
    ' 3 - invalid backgroundColor
    ' 4 - invalid message 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailurePageFont_Real(ByVal iSize As Integer, ByVal font As String, ByVal dblFillRed As Double, ByVal dblFillGreen As Double, ByVal dblFillBlue As Double, ByVal iStyle As Integer, ByVal dblOtherRed As Double, ByVal dblOtherGreen As Double, ByVal dblOtherBlue As Double) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailPgFnt_Real(ByVal iSize As Integer, ByVal font As String, ByVal dblFillRed As Double, ByVal dblFillGreen As Double, ByVal dblFillBlue As Double, ByVal iStyle As Integer, ByVal dblOtherRed As Double, ByVal dblOtherGreen As Double, ByVal dblOtherBlue As Double) As Integer
    End Function
    ' Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid font
    ' 3 - invalid fillRed
    ' 4 - invalid fillGreen
    ' 5 - invalid fillBlue
    ' 6 - invalid style
    ' 7 - invalid otherRed
    ' 8 - invalid otherGreen
    ' 9 - invalid otherBlue 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailurePageFont_Int(ByVal iSize As Integer, ByVal font As String, ByVal fillRed As Integer, ByVal fillGreen As Integer, ByVal fillBlue As Integer, ByVal iStyle As Integer, ByVal otherRed As Integer, ByVal otherGreen As Integer, ByVal otherBlue As Integer) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailPgFnt_Int(ByVal iSize As Integer, ByVal font As String, ByVal fillRed As Integer, ByVal fillGreen As Integer, ByVal fillBlue As Integer, ByVal iStyle As Integer, ByVal otherRed As Integer, ByVal otherGreen As Integer, ByVal otherBlue As Integer) As Integer
    End Function
    ' Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid font
    ' 3 - invalid fillRed
    ' 4 - invalid fillGreen
    ' 5 - invalid fillBlue
    ' 6 - invalid style
    ' 7 - invalid otherRed
    ' 8 - invalid otherGreen
    ' 9 - invalid otherBlue 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailurePageFont_Web(ByVal iSize As Integer, ByVal font As String, ByVal fillColor As String, ByVal iStyle As Integer, ByVal otherColor As String) As Integer
    End Function
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_LoadImageFailPgFnt_Web(ByVal iSize As Integer, ByVal font As String, ByVal fillColor As String, ByVal iStyle As Integer, ByVal otherColor As String) As Integer
    End Function
    ' Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid font
    ' 3 - invalid fillColor
    ' 4 - invalid style
    ' 5 - invalid otherColor 


    ' *****************************************************************************
    ' Bates (Page/Document) Numbering
    ' *****************************************************************************
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesFormat(ByVal format As String) As Long
    End Function
    ' Specifies the text to display on each page of the output PDF. This is typically
    ' a combination of static text plus one or more special Bates markup formatting labels.
    ' See the manual for full details.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid format


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesLocation(ByVal verticalPosition As Integer, ByVal horizontalPosition As Integer, ByVal orientation As Integer, ByVal margin As Double) As Long
    End Function
    ' This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid verticalPosition
    ' 2 - invalid horizontalPosition
    ' 3 - invalid textOrientation
    ' 4 - invalid margin 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesLocation_Int(ByVal verticalPosition As Integer, ByVal horizontalPosition As Integer, ByVal orientation As Integer, ByVal margin As Integer) As Long
    End Function
    ' This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid verticalPosition
    ' 2 - invalid horizontalPosition
    ' 3 - invalid textOrientation
    ' 4 - invalid margin 


    Public Const TEXT_STYLE_NORMAL As Integer = 1
    Public Const TEXT_STYLE_STROKE As Integer = 2
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesFont_Real(ByVal iSize As Integer, ByVal FontID As String, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal iStyle As Integer, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Long
    End Function
    ' This is optional and controls the display of the Bates "number". 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid fontID
    ' 3 - invalid fillRed
    ' 4 - invalid fillGreen
    ' 5 - invalid fillBlue
    ' 6 - invalid style
    ' 7 - invalid otherRed
    ' 8 - invalid otherGreen
    ' 9 - invalid otherBlue 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesFont_Int(ByVal iSize As Integer, ByVal FontID As String, ByVal fillRed As Integer, ByVal fillGreen As Integer, ByVal fillBlue As Integer, ByVal iStyle As Integer, ByVal otherRed As Integer, ByVal otherGreen As Integer, ByVal otherBlue As Integer) As Long
    End Function
    ' This is optional and controls the display of the Bates "number". 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid fontID
    ' 3 - invalid fillRed
    ' 4 - invalid fillGreen
    ' 5 - invalid fillBlue
    ' 6 - invalid style
    ' 7 - invalid otherRed
    ' 8 - invalid otherGreen
    ' 9 - invalid otherBlue 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesFont_Web(ByVal iSize As Integer, ByVal FontID As String, ByVal fillColor As String, ByVal iStyle As Integer, ByVal otherColor As String) As Long
    End Function
    ' This is optional and controls the display of the Bates "number". 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid size
    ' 2 - invalid fontID
    ' 3 - invalid fillColor
    ' 4 - invalid style
    ' 5 - invalid otherColor 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesFile(ByVal filename As String) As Long
    End Function
    ' This is optional but is useful if you want to have sequential numbering continue automatically between documents. 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid filename


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesNumber(ByVal initialValue As Integer) As Long
    End Function
    ' This is optional and defines the initial Bates number used. 
    '
    ' Return value:
    ' 0 - success


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesIncrement(ByVal value As Integer) As Long
    End Function
    ' This is optional and defines the amount by which the Bates number is incremented with use. 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid value


    Public Const BATES_BACKGROUND_FILLED_RECT As Integer = 1
    Public Const BATES_BACKGROUND_OUTLINE_RECT As Integer = 2
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesBackground_Real(ByVal shape As Integer, ByVal backgroundRed As Double, ByVal backgroundGreen As Double, ByVal backgroundBlue As Double, ByVal borderRed As Double, ByVal borderGreen As Double, ByVal borderBlue As Double) As Long
    End Function
    ' This is optional and if not specified no background is displayed behind the Bates "number". 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid shape
    ' 2 - invalid backgroundRed
    ' 3 - invalid backgroundGreen
    ' 4 - invalid backgroundBlue
    ' 5 - invalid borderRed
    ' 6 - invalid borderGreen
    ' 7 - invalid borderBlue 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesBackground_Int(ByVal shape As Integer, ByVal backgroundRed As Integer, ByVal backgroundGreen As Integer, ByVal backgroundBlue As Integer, ByVal borderRed As Integer, ByVal borderGreen As Integer, ByVal borderBlue As Integer) As Long
    End Function
    ' This is optional and if not specified no background is displayed behind the Bates "number". 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid shape
    ' 2 - invalid backgroundRed
    ' 3 - invalid backgroundGreen
    ' 4 - invalid backgroundBlue
    ' 5 - invalid borderRed
    ' 6 - invalid borderGreen
    ' 7 - invalid borderBlue 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_BatesBackground_Web(ByVal shape As Integer, ByVal backgroundColor As String, ByVal borderColor As String) As Long
    End Function
    ' This is optional and if not specified no background is displayed behind the Bates "number". 
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid shape
    ' 2 - invalid backgroundColor
    ' 3 - invalid borderColor 


    ' *****************************************************************************
    ' Image Transformations
    ' *****************************************************************************


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_Rotate(ByVal angle As Integer) As Integer
    End Function
    ' Rotate image clockwise by a fixed amount (90, 180 or 270 degrees)
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid angle


    Public Const AUTOROTATE_PORTRAIT As Integer = 1
    Public Const AUTOROTATE_LANDSCAPE As Integer = 2
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_AutoRotate(ByVal orientation As Integer, ByVal angle As Integer) As Integer
    End Function
    ' Rotate image clockwise (if required) by a fixed amount (90 or 270 degrees) 
    ' so that it is in portrait or landscape orientation
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid orientation
    ' 2 - invalid angle


    Public Const FLIP_HORIZONTAL As Integer = 1
    Public Const FLIP_VERTICAL As Integer = 2
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_Flip(ByVal orientation As Integer) As Integer
    End Function
    ' Flip image horizontally (mirroring) or vertically
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid orientation


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_Grayscale()
    End Sub
    ' Ensure that an image is in grayscale - if it is in color it will be converted
    '
    ' Return value:
    ' None


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_Negative()
    End Sub
    ' Invert (negative) image
    '
    ' Return value:
    ' None


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_JpegCompress(ByVal quality As Integer) As Integer
    End Function
    ' Force re-compression of all JPEG images, quality can be between 1 (low)
    ' to 35 (high). A value of 0 will turn re-compression off.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid angle


    ' *************************************************************************
    ' PDF Settings
    ' *************************************************************************
    Public Const OUTLINE_FORMAT_FILENAME As Integer = 1
    Public Const OUTLINE_FORMAT_NAME As Integer = 2
    Public Const STYLE_NONE As Integer = 0
    Public Const STYLE_LOWERCASE As Integer = 1
    Public Const STYLE_UPPERCASE As Integer = 2
    Public Const STYLE_CAPITALISE As Integer = 3

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetOutline(ByVal format As Integer, ByVal style As Integer) As Integer
    End Function
    ' This turns on the generation of a bookmark for each image that is in the 
    ' output PDF document.
    '
    ' format can be either "filename" (this is the name of the image file including 
    ' the image extension but not including the full filepath) or "name" (same as 
    ' filename but without the image extension).
    '
    ' style can be: "lowercase", "uppercase", "capitalise" or "none".
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid format parameter
    ' 2 - invalid style parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetOutlineTitle(ByVal title As String) As Integer
    End Function
    ' If an outline is created this will set the title to be used instead of the default one.
    '
    ' Return value:
    ' 0 - success
    ' 1 - title not specified
    ' 2 - title too long


    Public Const PDF_PERMISSION_READ_ONLY As Integer = 0
    Public Const PDF_PERMISSION_EDIT As Integer = 1
    Public Const PDF_PERMISSION_EDIT_EXTRA As Integer = 2
    Public Const PDF_PERMISSION_COPY As Integer = 4
    Public Const PDF_PERMISSION_PRINT As Integer = 8

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetPermissions(ByVal permissions As Integer) As Integer
    End Function
    ' Allows the setting of any combination of permissions in one go
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid permissions


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPermissionEdit()
    End Sub
    ' Allows editing/changing of the PDF document but NOT adding or changing of text 
    ' notes and AcroForm fields.
    '
    ' Return value: none 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPermissionEditExtra()
    End Sub
    ' Allows the adding and changing of text notes and AcroForm fields within a PDF document.
    '
    ' Return value: none 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPermissionCopy()
    End Sub
    ' Allows the copying of text and graphics from the PDF document.
    '
    ' Return value: none 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPermissionPrint()
    End Sub
    ' Allows printing of the PDF document.
    '
    ' Return value: none 


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetOwnerPassword(ByVal password As String) As Integer
    End Function
    ' The owner of a PDF document would enter this password in order to view it
    ' and make changes and perform actions that may be restricted to a normal user.
    '
    ' A maximum of 32 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetUserPassword(ByVal password As String) As Integer
    End Function
    ' In order that only the intended user can view the PDF document, they must type
    ' in this password, otherwise the user is not allowed to read the PDF document.
    '
    ' A maximum of 32 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_EncryptionLevel(ByVal level As Integer, ByVal force As Integer) As Integer
    End Function
    ' Specifies the level of encryption that is to be used on the PDF document. 
    ' If not specified the default level of 40 bits is used. 
    '
    ' level must be either 40 (low) or 128 (high)
    ' force must be 1 to force the encryption or 0
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MinImageSize(ByVal width As Integer, ByVal height As Integer) As Integer
    End Function
	' Specifies the minimum image width and height required for an image to be converted.
	'
	' width and height must be > 0
	'
	' Return value:
	' 0 - success
	' 1 - invalid width
	' 2 - invalid height


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetDPI(ByVal dpi As Integer) As Integer
    End Function
    ' PDF documents use a default resolution setting of 72 DPI. Images created for 
    ' screen display under Windows will probably have a resolution of 96 DPI. If you 
    ' have created images for printing then you will probably need to use 300 or 600 DPI.
    '
    ' If you do not adjust the default resolution setting then when displayed within a 
    ' PDF document on screen a 96 DPI image will appear 25% larger than expected. This 
    ' gets much worse for a 300 DPI image which will appear 416% larger than expected.
    '
    ' dpi must be between 9 and 2880 inclusive, or 0 to force the use of the actual
    ' image dpi that is recorded in the image file
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter - dpi specified is less than 9
    ' 2 - invalid parameter - dpi specified is greater than 2880


    ' *************************************************************************
    ' PDF Meta Information
    ' *************************************************************************
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetProducer(ByVal producer As String) As Integer
    End Function
    ' The name of the application that converted the document from its native format to PDF.
    '
    ' A maximum of 256 characters can be used.
    ' 
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetCreator(ByVal creator As String) As Integer
    End Function
    ' If the document was converted into a PDF document from another form, this is 
    ' usually the name of the application that created the original document.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetAuthor(ByVal author As String) As Integer
    End Function
    ' The name of the person who created the PDF document.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetTitle(ByVal title As String) As Integer
    End Function
    ' The PDF document's title.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetSubject(ByVal subject As String) As Integer
    End Function
    ' The PDF document's subject.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_SetKeywords(ByVal keywords As String) As Integer
    End Function
    ' A list of keywords associated with the PDF document.
    '
    ' A maximum of 256 characters can be used.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetCreationDate()
    End Sub
    ' The date that the PDF document was created.
    '
    ' This is set using the current local time of the PC.
    '
    ' Return value: none


    ' *************************************************************************
    ' PDF Viewer Preferences
    ' *************************************************************************
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewerPreferenceCenterWindow()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewPrefCenterWindow()
    End Sub
    ' The window displaying the PDF document should be displayed in the center of 
    ' the computer's screen.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewerPreferenceHideToolbar()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewPrefHideToolbar()
    End Sub
    ' The PDF viewer's toolbar should be hidden when the PDF document is active.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewerPreferenceHideMenubar()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewPrefHideMenubar()
    End Sub
    ' The PDF viewer's menubar should be hidden when the PDF document is active.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewerPreferenceHideWindowUI()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewPrefHideWindowUI()
    End Sub
    ' The user interface elements within the PDF document's window should be hidden.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewerPreferenceFitWindow()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetViewPrefFitWindow()
    End Sub
    ' The PDF viewer should resize the window displaying the PDF document to fit the 
    ' size of the first displayed page of the PDF document.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageModeOutlines()
    End Sub
    ' The PDF viewer should show the outline (ie bookmark) navigation item when the 
    ' PDF document is open.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageModeNone()
    End Sub
    ' The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
    ' items when the PDF document is open.
    '
    ' This is the default if no other page mode is specified.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageModeUseThumbs()
    End Sub
    ' The PDF viewer should show the thumbnail navigation item when the PDF document 
    ' is open.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageModeFullScreen()
    End Sub
    ' The PDF viewer should open the PDF document in full-screen mode without showing 
    ' the menu bar, window controls or any other window.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayoutSinglePage()
    End Sub
    ' Display the pages one page at a time.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayoutOneColumn()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayout1Col()
    End Sub
    ' Display the pages in one column.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayoutTwoColumnLeft()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayout2ColLeft()
    End Sub
    ' Display the pages in two columns, with odd-numbered pages on the left.
    '
    ' Return value: none


    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayoutTwoColumnRight()
    End Sub
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_SetPageLayout2ColRight()
    End Sub
    ' Display the pages in two columns, with odd-numbered pages on the right.
    '
    ' Return value: none


    ' *************************************************************************
    ' Specifies the name and location of the produced PDF document, 
    ' *************************************************************************
    Public Const OPTION_NONE As Integer = 0
    Public Const OPTION_OPEN_PDF As Integer = 1
    Public Const OPTION_RESET As Integer = 2
    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Function I2PDF_MakePDF(ByVal output As String, ByVal options As Integer, ByRef errorText As String, ByVal maxErrorTextSize As Integer) As Integer
    End Function
    ' Generate the output PDF according to the settings already selected through
    ' the Application Programming Interface functions above.
    '
    ' To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
    ' bit flag in the options parameter.
    '
    ' To have all settings applied reset after PDF has been generated set the OPTION_RESET
    ' bit flag in the options parameter.
    '
    ' Return value:
    ' 0 - success
    ' 1 - invalid parameter
    ' 2 - output pdf could not be opened
    ' 3 - internal PDF generation error - error description returned in errorText
    ' 4 - PDF file already exists and could not be overwritten - it is possibly being held open by a PDF viewer application

    <DllImport("Image2PDF.dll", CallingConvention:=CallingConvention.Cdecl)> _
    Public Shared Sub I2PDF_Reset()
    End Sub
    ' Reset all settings including the list of images added.
    '
    ' Return value: none
End Class
